@@ -2,8 +2,12 @@
 from __future__ import with_statement
 import os
 import dj_database_url
-from cms.utils.compat import DJANGO_1_5, DJANGO_1_6, PY2
+
 import django
+from django.utils import six
+
+from cms.utils.compat import DJANGO_1_5, DJANGO_1_6
+
 
 gettext = lambda s: s
 
@@ -12,10 +16,10 @@ urlpatterns = []
 
 def configure(db_url, **extra):
     from django.conf import settings
-    if PY2:
-        siteid = long(1)  # nopyflakes
-    else:
+    if six.PY3:
         siteid = 1
+    else:
+        siteid = long(1)  # nopyflakes
 
     os.environ['DJANGO_SETTINGS_MODULE'] = 'cms.test_utils.cli'
     if not 'DATABASES' in extra:
@@ -264,6 +268,33 @@ def configure(db_url, **extra):
 
     if DJANGO_1_6:
         defaults['INSTALLED_APPS'].append('south')
+    else:
+        defaults['MIGRATION_MODULES'] = {
+            'cms': 'cms.migrations_django',
+            'menus': 'menus.migrations_django',
+            'djangocms_column': 'djangocms_column.migrations_django',
+            'djangocms_file': 'djangocms_file.migrations_django',
+            'djangocms_flash': 'djangocms_flash.migrations_django',
+            'djangocms_googlemap': 'djangocms_googlemap.migrations_django',
+            'djangocms_inherit': 'djangocms_inherit.migrations_django',
+            'djangocms_link': 'djangocms_link.migrations_django',
+            'djangocms_picture': 'djangocms_picture.migrations_django',
+            'djangocms_style': 'djangocms_style.migrations_django',
+            'djangocms_teaser': 'djangocms_teaser.migrations_django',
+            'djangocms_text_ckeditor': 'djangocms_text_ckeditor.migrations_django',
+            'djangocms_video': 'djangocms_video.migrations_django',
+            'meta': 'cms.test_utils.project.pluginapp.plugins.meta.migrations_django',
+            'manytomany_rel': 'cms.test_utils.project.pluginapp.plugins.manytomany_rel.migrations_django',
+            'fileapp': 'cms.test_utils.project.fileapp.migrations_django',
+            'placeholderapp': 'cms.test_utils.project.placeholderapp.migrations_django',
+            'sampleapp': 'cms.test_utils.project.sampleapp.migrations_django',
+            'fakemlng': 'cms.test_utils.project.fakemlng.migrations_django',
+            'extra_context': 'cms.test_utils.project.pluginapp.plugins.extra_context.migrations_django',
+            'one_thing': 'cms.test_utils.project.pluginapp.plugins.one_thing.migrations_django',
+            'bunch_of_plugins': 'cms.test_utils.project.bunch_of_plugins.migrations_django',
+            'extensionapp': 'cms.test_utils.project.extensionapp.migrations_django',
+            'objectpermissionsapp': 'cms.test_utils.project.objectpermissionsapp.migrations_django',
+        }
     if DJANGO_1_5:
         defaults['MIDDLEWARE_CLASSES'].append('django.middleware.transaction.TransactionMiddleware')
 
