@@ -2,6 +2,7 @@
 from __future__ import with_statement
 import json
 import datetime
+from cms.utils.urlutils import admin_reverse
 
 from djangocms_text_ckeditor.cms_plugins import TextPlugin
 from djangocms_text_ckeditor.models import Text
@@ -341,7 +342,7 @@ class AdminTestCase(AdminTestsBase):
                     continue
                 if not admin_instance.search_fields:
                     continue
-                url = reverse('admin:cms_%s_changelist' % model._meta.module_name)
+                url = admin_reverse('cms_%s_changelist' % model._meta.module_name)
                 response = self.client.get('%s?q=1' % url)
                 errmsg = response.content
                 self.assertEqual(response.status_code, 200, errmsg)
@@ -373,7 +374,7 @@ class AdminTestCase(AdminTestsBase):
             original_end_date = draft.publication_end_date
             new_date = timezone.now() - datetime.timedelta(days=1)
             new_end_date = timezone.now() + datetime.timedelta(days=1)
-            url = reverse('admin:cms_page_dates', args=(draft.pk,))
+            url = admin_reverse('cms_page_dates', args=(draft.pk,))
             with self.login_user_context(admin_user):
                 response = self.client.post(url, {
                     'language': 'en',
@@ -396,7 +397,7 @@ class AdminTestCase(AdminTestsBase):
             original_end_date = draft.publication_end_date
             new_date = timezone.localtime(timezone.now()) - datetime.timedelta(days=1)
             new_end_date = timezone.localtime(timezone.now()) + datetime.timedelta(days=1)
-            url = reverse('admin:cms_page_dates', args=(draft.pk,))
+            url = admin_reverse('cms_page_dates', args=(draft.pk,))
             with self.login_user_context(admin_user):
                 response = self.client.post(url, {
                     'language': 'en',
@@ -424,7 +425,7 @@ class AdminTestCase(AdminTestsBase):
             page = create_page('test-page', 'nav_playground.html', 'en')
             response = pageadmin.change_template(request, page.pk)
             self.assertEqual(response.status_code, 403)
-        url = reverse('admin:cms_page_change_template', args=(page.pk,))
+        url = admin_reverse('cms_page_change_template', args=(page.pk,))
         with self.login_user_context(admin_user):
             response = self.client.post(url, {'template': 'doesntexist'})
             self.assertEqual(response.status_code, 400)
@@ -433,7 +434,7 @@ class AdminTestCase(AdminTestsBase):
 
     def test_get_permissions(self):
         page = create_page('test-page', 'nav_playground.html', 'en')
-        url = reverse('admin:cms_page_get_permissions', args=(page.pk,))
+        url = admin_reverse('cms_page_get_permissions', args=(page.pk,))
         response = self.client.get(url)
         if DJANGO_1_6:
             self.assertEqual(response.status_code, 200)
@@ -459,7 +460,7 @@ class AdminTestCase(AdminTestsBase):
                                        created_by=admin_user, published=True, parent=second_level_page_top)
         self.assertEqual(Page.objects.all().count(), 4)
 
-        url = reverse('admin:cms_%s_changelist' % Page._meta.module_name)
+        url = admin_reverse('cms_%s_changelist' % Page._meta.module_name)
         request = self.get_request(url)
 
         request.session = {}
@@ -501,7 +502,7 @@ class AdminTestCase(AdminTestsBase):
         third_level_page = create_page('level3', "nav_playground.html", "en",
                                        created_by=admin_user, published=True, parent=second_level_page_top)
 
-        url = reverse('admin:cms_%s_changelist' % Page._meta.module_name)
+        url = admin_reverse('cms_%s_changelist' % Page._meta.module_name)
 
         if get_user_model().USERNAME_FIELD == 'email':
             self.client.login(username='admin@django-cms.org', password='admin@django-cms.org')
@@ -550,7 +551,7 @@ class AdminTestCase(AdminTestsBase):
         # Add a es-mx translation for this page
         create_title("es-mx", es_title, page, slug="es_pagina")
 
-        url = reverse('admin:cms_%s_changelist' % Page._meta.module_name)
+        url = admin_reverse('cms_%s_changelist' % Page._meta.module_name)
         url_pat = '<a href="{0}/{1}/preview/"[^>]*>{2}</a>'
 
         with self.login_user_context(admin_guy):
@@ -706,7 +707,7 @@ class AdminTests(AdminTestsBase):
         admin_user = self.get_admin()
         self.page.publish("en")  # Ensure public copy exists before reverting
         with self.login_user_context(admin_user):
-            response = self.client.get(reverse('admin:cms_page_revert_page', args=(self.page.pk, 'en')))
+            response = self.client.get(admin_reverse('cms_page_revert_page', args=(self.page.pk, 'en')))
             self.assertEqual(response.status_code, 302)
             url = response['Location']
             self.assertTrue(url.endswith('?%s' % get_cms_setting('CMS_TOOLBAR_URL__EDIT_OFF')))
@@ -818,7 +819,7 @@ class AdminTests(AdminTestsBase):
             },
         }
         admin_user = self.get_admin()
-        url = reverse('admin:cms_page_add_plugin')
+        url = admin_reverse('cms_page_add_plugin')
         with SettingsOverride(CMS_PERMISSION=False,
                               CMS_PLACEHOLDER_CONF=conf):
             page = create_page('somepage', 'nav_playground.html', 'en')
@@ -842,7 +843,7 @@ class AdminTests(AdminTestsBase):
             },
         }
         admin_user = self.get_admin()
-        url = reverse('admin:cms_page_add_plugin')
+        url = admin_reverse('cms_page_add_plugin')
         with SettingsOverride(CMS_PERMISSION=False,
                               CMS_PLACEHOLDER_CONF=conf):
             page = create_page('somepage', 'nav_playground.html', 'en')
@@ -979,7 +980,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='admin', password='admin')
 
-        url = reverse('admin:cms_page_add_plugin')
+        url = admin_reverse('cms_page_add_plugin')
         data = {
             'plugin_type': 'TextPlugin',
             'placeholder_id': self._placeholder.pk,
@@ -1002,7 +1003,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='test', password='test')
 
-        url = reverse('admin:cms_page_edit_plugin', args=[plugin.id])
+        url = admin_reverse('cms_page_edit_plugin', args=[plugin.id])
         response = self.client.post(url, dict())
         self.assertEqual(response.status_code, HttpResponseForbidden.status_code)
         # After he got the permissions, he can edit the plugin
@@ -1020,7 +1021,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='test', password='test')
 
-        url = reverse('admin:cms_page_delete_plugin', args=[plugin.pk])
+        url = admin_reverse('cms_page_delete_plugin', args=[plugin.pk])
         data = dict(plugin_id=plugin.id)
         response = self.client.post(url, data)
         self.assertEqual(response.status_code, HttpResponseForbidden.status_code)
@@ -1039,7 +1040,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='test', password='test')
 
-        url = reverse('admin:cms_page_move_plugin')
+        url = admin_reverse('cms_page_move_plugin')
         data = dict(plugin_id=plugin.id,
                     placeholder_id=self._placeholder.pk,
                     plugin_parent='',
@@ -1061,7 +1062,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='test', password='test')
 
-        url = reverse('admin:cms_page_copy_plugins')
+        url = admin_reverse('cms_page_copy_plugins')
         data = dict(source_plugin_id=plugin.id,
                     source_placeholder_id=self._placeholder.pk,
                     source_language='en',
@@ -1094,7 +1095,7 @@ class PluginPermissionTests(AdminTestsBase):
         else:
             self.client.login(username='admin', password='admin')
 
-        url = reverse('admin:cms_page_copy_plugins')
+        url = admin_reverse('cms_page_copy_plugins')
         data = dict(source_plugin_id='',
                     source_placeholder_id=self._placeholder.pk,
                     source_language='en',
@@ -1123,7 +1124,7 @@ class PluginPermissionTests(AdminTestsBase):
         self.assertEqual(plugins.count(), 4)
         self.assertEqual(CMSPlugin.objects.count(), 7)
         self.assertEqual(Placeholder.objects.count(), 4)
-        url = reverse('admin:cms_page_clear_placeholder', args=[clipboard.pk])
+        url = admin_reverse('cms_page_clear_placeholder', args=[clipboard.pk])
         with self.assertNumQueries(FuzzyInt(70, 80)):
             response = self.client.post(url, {'test': 0})
         self.assertEqual(response.status_code, 302)
@@ -1141,7 +1142,7 @@ class PluginPermissionTests(AdminTestsBase):
             self.client.login(username='test@test.com', password='test@test.com')
 
         self.assertEqual(1, CMSPlugin.objects.all().count())
-        url = reverse('admin:cms_page_copy_language', args=[self._page.pk])
+        url = admin_reverse('cms_page_copy_language', args=[self._page.pk])
         data = dict(
             source_language='en',
             target_language='fr',
@@ -1229,7 +1230,7 @@ class PluginPermissionTests(AdminTestsBase):
         username = getattr(admin_user, get_user_model().USERNAME_FIELD)
         self.client.login(username=username, password='admin')
 
-        url = reverse('admin:cms_page_add_plugin')
+        url = admin_reverse('cms_page_add_plugin')
         data = {
             'plugin_type': 'TextPlugin',
             'placeholder_id': self._placeholder.pk,
@@ -1348,7 +1349,7 @@ class AdminFormsTests(AdminTestsBase):
         superuser = self.get_superuser()
         with self.login_user_context(superuser):
             response = self.client.get(
-                "%s?copy_target=%s&language=%s" % (reverse("admin:cms_page_add_page_type"), page.pk, 'en'))
+                "%s?copy_target=%s&language=%s" % (admin_reverse("cms_page_add_page_type"), page.pk, 'en'))
             self.assertEqual(response.status_code, 302)
             self.assertEqual(Page.objects.count(), 3)
             self.assertEqual(Page.objects.filter(reverse_id="page_types").count(), 1)
@@ -1359,11 +1360,11 @@ class AdminFormsTests(AdminTestsBase):
             response_url_params = QueryDict(urlparse(url).query)
             self.assertDictEqual(expected_url_params, response_url_params)
             response = self.client.get("%s?copy_target=%s&language=%s" % (
-                reverse("admin:cms_page_add_page_type"), page.pk, 'en'), follow=True)
+                admin_reverse("cms_page_add_page_type"), page.pk, 'en'), follow=True)
             self.assertEqual(response.status_code, 200)
 
             # test no page types if no page types there
-            response = self.client.get(reverse('admin:cms_page_add'))
+            response = self.client.get(admin_reverse('cms_page_add'))
             self.assertNotContains(response, "page_type")
             # create out first page type
             page_data = {
@@ -1376,10 +1377,10 @@ class AdminFormsTests(AdminTestsBase):
             self.assertEqual(response.status_code, 302)
             self.assertEqual(Page.objects.count(), 4)
             self.assertEqual(CMSPlugin.objects.count(), 6)
-            response = self.client.get(reverse('admin:cms_page_add'))
+            response = self.client.get(admin_reverse('cms_page_add'))
             self.assertContains(response, "page_type")
             # no page types available if you use the copy_target
-            response = self.client.get("%s?copy_target=%s&language=en" % (reverse('admin:cms_page_add'), page.pk))
+            response = self.client.get("%s?copy_target=%s&language=en" % (admin_reverse('cms_page_add'), page.pk))
             self.assertNotContains(response, "page_type")
 
     def test_render_edit_mode(self):
