@@ -6,6 +6,7 @@ from django.core.urlresolvers import clear_url_caches, reverse
 from django.utils import six
 
 from cms.api import create_page, create_title
+from cms.app_base import CMSApp
 from cms.apphook_pool import apphook_pool
 from cms.appresolver import applications_page_check, clear_app_resolvers, get_app_patterns
 from cms.models import Title
@@ -15,6 +16,7 @@ from cms.tests.menu_utils import DumbPageLanguageUrl
 from cms.utils.compat.dj import get_user_model
 from cms.utils.conf import get_cms_setting
 from cms.utils.i18n import force_language
+from menus.utils import DefaultLanguageChanger
 
 
 APP_NAME = 'SampleApp'
@@ -319,6 +321,23 @@ class ApphooksTestCase(CMSTestCase):
 
             apphook_pool.clear()
 
+    def test_default_language_changer_with_implicit_current_app(self):
+        with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
+            titles = self.create_base_structure(NS_APP_NAME, ['en', 'de'], 'namespaced_app_ns')  # nopyflakes
+            self.reload_urls()
+            with force_language("en"):
+                path = reverse('namespaced_app_ns:translated-url')
+            request = self.get_request(path)
+            request.LANGUAGE_CODE = 'en'
+
+            url = DefaultLanguageChanger(request)('en')
+            self.assertEqual(url, path)
+
+            url = DefaultLanguageChanger(request)('de')
+            self.assertEqual(url, '/de%s' % path[3:].replace('/page', '/Seite'))
+
+            apphook_pool.clear()
+
     def test_get_i18n_apphook_with_explicit_current_app(self):
         with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
             titles = self.create_base_structure(NS_APP_NAME, ['en', 'de'], 'instance_1')
@@ -350,9 +369,6 @@ class ApphooksTestCase(CMSTestCase):
                 reverse('namespaced_app_ns:current-app', current_app="instance_2")
                 reverse('namespaced_app_ns:current-app')
 
-
-
-
     def test_apphook_include_extra_parameters(self):
         with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
             self.create_base_structure(NS_APP_NAME, ['en', 'de'], 'instance_1')
@@ -467,6 +483,20 @@ class ApphooksTestCase(CMSTestCase):
 
             apphook_pool.clear()
 
+    def test_apphook_pool_register_returns_apphook(self):
+        @apphook_pool.register
+        class TestApp(CMSApp):
+            name = "Test App"
+        self.assertIsNotNone(TestApp)
+
+        # Now test the quick return codepath, when apphooks is not empty
+        apphook_pool.apphooks.append("foo")
+
+        @apphook_pool.register
+        class TestApp2(CMSApp):
+            name = "Test App 2"
+        self.assertIsNotNone(TestApp2)
+
 
 class ApphooksPageLanguageUrlTestCase(SettingsOverrideTestCase):
     settings_overrides = {'ROOT_URLCONF': 'cms.test_utils.project.second_urls_for_apphook_tests'}
