@@ -1,19 +1,15 @@
 # -*- coding: utf-8 -*-
 # TODO: this is just stuff from utils.py - should be splitted / moved
-from cms import constants
-from cms.utils.conf import get_cms_setting
-from cms.utils.i18n import get_default_language, get_language_list, get_language_code
-from distutils.version import LooseVersion
 from django.conf import settings
 from django.core.files.storage import get_storage_class
-from django.core.urlresolvers import reverse
-from django.http import HttpResponse, HttpResponseRedirect
-from django.shortcuts import render_to_response
-from django.template import RequestContext
 from django.utils.functional import LazyObject
-import django
-import os
-import urllib
+
+from cms import constants
+from cms.utils.conf import get_cms_setting
+from cms.utils.conf import get_site_id  # nopyflakes
+from cms.utils.i18n import get_default_language
+from cms.utils.i18n import get_language_list
+from cms.utils.i18n import get_language_code
 
 
 def get_template_from_request(request, obj=None, no_current_page=False):
@@ -72,16 +68,6 @@ def get_language_from_request(request, current_page=None):
 
     return language
 
-
-def get_page_from_request(request):
-    from warnings import warn
-    from cms.utils.page_resolver import get_page_from_request as new
-    warn("'cms.utils.get_page_from_request' is deprecated in favor of "
-         "'cms.utils.page_resolver.get_page_from_request' and will be removed "
-         "in Django-CMS 2.2.", DeprecationWarning)
-    return new(request)
-
-
 default_storage = 'django.contrib.staticfiles.storage.StaticFilesStorage'
 
 
@@ -90,11 +76,3 @@ class ConfiguredStorage(LazyObject):
         self._wrapped = get_storage_class(getattr(settings, 'STATICFILES_STORAGE', default_storage))()
 
 configured_storage = ConfiguredStorage()
-
-def cms_static_url(path):
-    '''
-    Helper that prefixes a URL with STATIC_URL and cms
-    '''
-    if not path:
-        return ''
-    return configured_storage.url(os.path.join('cms', path))
