@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 from __future__ import with_statement
+from contextlib import contextmanager
+import inspect
+import warnings
+from cms.models.titlemodels import Title
 from cms.utils import get_language_from_request
+from cms.utils.compat import DJANGO_1_6
 from cms.utils.i18n import force_language, hide_untranslated
 from django.conf import settings
 from django.core.urlresolvers import NoReverseMatch, reverse, resolve
-
-import warnings
-from cms.models.titlemodels import Title
-
+from django.utils import six
 
 
 def mark_descendants(nodes):
@@ -15,6 +17,7 @@ def mark_descendants(nodes):
         node.descendant = True
         mark_descendants(node.children)
 
+
 def cut_levels(nodes, level):
     """
     For cutting the nav_extender levels if you have a from_level in the navigation.
@@ -27,6 +30,7 @@ def cut_levels(nodes, level):
         result += cut_levels(node.children, level)
     return result
 
+
 def find_selected(nodes):
     """
     Finds a selected nav_extender node 
@@ -55,6 +59,7 @@ def set_language_changer(request, func):
     """
     request._language_changer = func
 
+
 def language_changer_decorator(language_changer):
     """
     A decorator wrapper for set_language_changer.
@@ -126,22 +131,14 @@ class DefaultLanguageChanger(object):
         elif view and not view.url_name in ('pages-details-by-slug', 'pages-root'):
             view_name = view.url_name
             if view.namespace:
-                "%s:%s" % (view.namespace, view_name)
+                view_name = "%s:%s" % (view.namespace, view_name)
             url = None
-            # every class-level argument is instantiated
-            # before reversing as reverse does not support
-            # classes as arguments
-            for idx, arg in enumerate(view.args):
-                if isinstance(arg, type):
-                    view.args[idx] = arg()
-            for key, arg in view.kwargs.items():
-                if isinstance(arg, type):
-                    view.kwargs[key] = arg()
             with force_language(lang):
-                try:
-                    url = reverse(view_name, args=view.args, kwargs=view.kwargs, current_app=view.app_name)
-                except NoReverseMatch:
-                    pass
+                with static_stringifier(view):  # This is a fix for Django < 1.7
+                    try:
+                        url = reverse(view_name, args=view.args, kwargs=view.kwargs, current_app=view.app_name)
+                    except NoReverseMatch:
+                        pass
             if url:
                 return url
         return '%s%s' % (self.get_page_path(lang), self.app_path)
@@ -158,3 +155,44 @@ def simple_language_changer(func):
     _wrapped.__name__ = func.__name__
     _wrapped.__doc__ = func.__doc__
     return _wrapped
+
+
+@contextmanager
+def static_stringifier(view):
+    """
+    In Django < 1.7 reverse tries to convert to string the arguments without
+    checking whether they are classes or instances.
+
+    This context manager monkeypatches the __unicode__ method of each view
+    argument if it's a class definition to render it a static method.
+    Before leaving we undo the monkeypatching.
+    """
+    if DJANGO_1_6:
+        for idx, arg in enumerate(view.args):
+            if inspect.isclass(arg):
+                if hasattr(arg, '__unicode__'):
+                    @staticmethod
+                    def custom_str():
+                        return six.text_type(arg)
+                    arg._original = arg.__unicode__
+                    arg.__unicode__ = custom_str
+                view.args[idx] = arg
+        for key, arg in view.kwargs.items():
+            if inspect.isclass(arg):
+                if hasattr(arg, '__unicode__'):
+                    @staticmethod
+                    def custom_str():
+                        return six.text_type(arg)
+                    arg._original = arg.__unicode__
+                    arg.__unicode__ = custom_str
+                view.kwargs[key] = arg
+    yield
+    if DJANGO_1_6:
+        for idx, arg in enumerate(view.args):
+            if inspect.isclass(arg):
+                if hasattr(arg, '__unicode__'):
+                    arg.__unicode__ = arg._original
+        for key, arg in view.kwargs.items():
+            if inspect.isclass(arg):
+                if hasattr(arg, '__unicode__'):
+                    arg.__unicode__ = arg._original
\ No newline at end of file
